@@ -1,20 +1,5 @@
-/*
-Copyright (C) 2001 - 2013 Evan Teran
-                          evan.teran@gmail.com
-
-This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2001-2013 Evan Teran <evan.teran@gmail.com>
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef KNUMBER_H_
 #define KNUMBER_H_
@@ -110,7 +95,7 @@ public:
 	KNumber integerPart() const;
 
 public:
-    QString toQString(int width = 16, int precision = -1) const;
+    QString toQString(int width = 64, int precision = -1) const;
     QString toBinaryString(int precision) const;
     QString toHexString(int precision) const;
 	quint64 toUint64() const;
